package Acme::Greeting::en;

# No code

1;

__DATA__

=head1 NAME

Acme::Greeting::en - How people do greeting in English.

=head1 DESCRIPTION

This document list what people says as a greeting.

=over

=item Greeting, $u

=item Hello, $u

=item Hiya, $u

Informal.

=item Yo, man

Informal. Use only when you see your friend.

=back

=cut
