package Acme::Greeting::en;
use utf8;

# No code

1;

__DATA__

=head1 NAME

Acme::Greeting::zh_tw - How people do greeting in English.

=head1 DESCRIPTION

這份文件列出一般講中文的人們打招呼的方式。

=over

=item 您好, $u

=item 哈囉, $u

=item 早啊, $u

當然只在早上才會這麼說。

=item 嘿

口語化。只用在朋友之間。若用於不熟的人，多半是不禮貌的語氣。

=back

=cut
